# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/atlassianhw',
                'doc_host': 'https://jazon33y.github.io',
                'git_url': 'https://github.com/jazon33y/atlassianhw',
                'lib_path': 'atlassianhw'},
  'syms': { 'atlassianhw.data': { 'atlassianhw.data.AData': ('data.html#adata', 'atlassianhw/data.py'),
                                  'atlassianhw.data.AData.__init__': ('data.html#adata.__init__', 'atlassianhw/data.py'),
                                  'atlassianhw.data.AData.__repr__': ('data.html#adata.__repr__', 'atlassianhw/data.py'),
                                  'atlassianhw.data.AData.__str__': ('data.html#adata.__str__', 'atlassianhw/data.py'),
                                  'atlassianhw.data.AData._clean_data': ('data.html#adata._clean_data', 'atlassianhw/data.py'),
                                  'atlassianhw.data.AData.clean_data': ('data.html#adata.clean_data', 'atlassianhw/data.py'),
                                  'atlassianhw.data.AData.remove_duplicate_by_col': ( 'data.html#adata.remove_duplicate_by_col',
                                                                                      'atlassianhw/data.py'),
                                  'atlassianhw.data.AData.remove_missing_by_col': ( 'data.html#adata.remove_missing_by_col',
                                                                                    'atlassianhw/data.py')},
            'atlassianhw.utils': { 'atlassianhw.utils.bar_plot': ('utils.html#bar_plot', 'atlassianhw/utils.py'),
                                   'atlassianhw.utils.rawdata': ('utils.html#rawdata', 'atlassianhw/utils.py')}}}
